#[repr(u8)]pub enum Prefovr {
NORMAL = 0,
OVERRIDE = 1,
}Variants
NORMAL = 0
Any previously initiated prefetch will be completed.
OVERRIDE = 1
Any previously initiated prefetch will be aborted, and the next flash line following the current execution address will be prefetched if not already buffered.
Implementations